#
# spec file for package python-python-debian
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2017 Free Software Foundation Europe e.V.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-python-debian
Version:        0.1.49
Release:        1.7
Summary:        Debian package related modules
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://salsa.debian.org/python-debian-team/python-debian
Source:         https://files.pythonhosted.org/packages/source/p/python-debian/python-debian-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-chardet
Requires:       python-six
Requires:       zstd
BuildArch:      noarch
Provides:       python-debian = %{version}-%{release}
Obsoletes:      python-debian < %{version}-%{release}
%python_subpackages

%description
This is a collection of modules that are for dealing with Debian related
data. Currently handled are:

* Debtags information (debian.debtags module)
* debian/changelog (debian.changelog module)
* Packages files, pdiffs (debian.debian_support module)
* Control files of single or multiple RFC822-style paragraphs, e.g.
  debian/control, .changes, .dsc, Packages, Sources, Release, etc.
  (debian.deb822 module)
* Raw .deb and .ar files, with (read-only) access to contained
  files and meta-information

%prep
%setup -q -n python-debian-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.rst
%{python_sitelib}/*

%changelog
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.1.49
  * Fix whitespace handling of Copyright files (Closes: #960278)
  * Make python-debian (more) portable (Closes: #1011937)
  - Tweak tests to be portable to other platforms
  - Adapt tests so that skipping optional tests can be prevented if needed
  - Add other platforms to CI to test portability
  * Switch tests to use more pytest features.
  * Updates for newer mypy and pylint.
  * Add Debian 14 'forky' to the list of known releases.
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.1.48
  * Fix version bound for subscripting abc.Iterator, abc.MutableMapping
  * Don't raise AmbiguousDeb822FieldKeyError in __contains__.
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.1.47
  Following is the changelog for deb822 before it was merged into python-debian.
  * deb822.py:
  - Allow Deb822 objects to be initialized with a dict containing the initial
    key-value pairs.
  - _multivalued class:
    + Make all the multivalued dicts Deb822Dict objects, so the keys are
    case-preserving, but case-insensitive
  - Add a Release class, which knows about Release-file multivalued fields.
    Thanks to Alexandre Fayolle.  (Closes: 428540)
  - Deb822Dict no longer directly subclasses dict.  All of the important
    methods were already implemented with userdict.DictMixin; the dict
    subclass was so that Python would see a Deb822Dict instance as a dict
    instance.  Unfortunately, this causes confusion if you do something like
    d = dict(Deb822Dict({'foo': 'bar'})
    The "Pythonic" way to check for a dictionary interface is to check for
    the 'items' attribute.
  * test_deb822.py:
  - Add a test case for deriving a Python dict from a Deb822Dict.
  * debian/control:
  - Add a XS-Vcs-Bzr field
* Mon Jul  4 2022 Matej Cepl <mcepl@suse.com>
- Fix Homepage
- Rename package according to the Python packaging
  guidelines (jsc#SLE-24672)
* Mon Jun 27 2022 Julio González Gil <jgonzalez@suse.com>
- Update to 0.1.44 (jsc#SLE-24672)
  * Add support for zstd compression in .deb files
  * Use logging.warning rather than warnings for data problems.
  * Support for finding files (including changelog.Debian.gz) that are beyond
    a symlink within the package
  * Update packaging for zstd compressed .deb code
  * Annotate binutils build-dep with <!nocheck>
  * Update Standards-Version to 4.6.1
  * Various improvements to the round-trip-safe deb822 parser
- Update to 0.1.43
  * Support the Files-Included field in debian/copyright
  * Fix URL for API documentation in README.rst
  * RTS parser: minor documentation fixes
  * Declare minimum Python version of 3.5 for most modules except the
    RTS parser. Add CI testing with Python 3.5
  * RTS parser: Handle leading tabs for setting values
  * RTS parser: Preserve original field case
  * RTS parser: Expose str type for keys in paragraphs
- Update to 0.1.42
  * Use logging for warnings about data that's being read, rather than
    the warnings module
  * Fix type checks for mypy 0.910
  * Silence lintian complaint about touching the dpkg database in the
    examples
  * Update Standards-Version to 4.6.0
  * Add RTS parser to setup.py so that it is installed.
  * Add copyright attribution for RTS parser
  * RTS parser: Accept tabs as continuation line marker
  * Interpretation: Preserve tab as continuation line if used
  * RTS parser: Make value interpretation tokenization consistent
  * RTS parser: Add interpretation for Uploaders field
- Update to 0.1.41
  * Drop use of six
  * Add contextmanager to DebFile
  * Added format/comment preserving deb822 parser as debian._deb822_repro.
  * Add Build-Depends-Arch, Build-Conflicts-Arch to list of relationship
    fields
- Update to 0.1.40
  * In debian.changelog.get_maintainer, cope with unknown UIDs
  * Fix examples in code
  * Numerous enhancements to the deb822.BuildInfo class
  * Include portability patch for pwd module on Windows
  * Drop the deb822.BuildInfo.get_debian_suite function
- Update to 0.1.39
  * Move re.compile calls out of functions
  * Revert unintended renaming of Changelog.get_version/set_version
  * Add a type for .buildinfo files (deb822.BuildInfo)
  * Add support for SHA1-Download and SHA256-* variants in PdiffIndex class
    for .diff/Index files
  * Permit single-character package names in dependency relationship
    specifications
  * Update Standards-Version to 4.5.1 (no changes required)
  * Update to debhelper-compat (= 13)
  * Update examples to use #!/usr/bin/python3
  * Fix tabs vs spaces in examples.
  * Provide accessor for source package version for binary packages
  * Allow debian_support.PackageFile to accept StringIO as well as BytesIO
  * Change handling of case-insensitive field names to allow Deb822 objects
    to be serialised
  * Update Standards-Version to 4.5.1 (no changes required)
  * Update to debhelper-compat (= 13)
  * Update examples to use #!/usr/bin/python3
  * Fix tabs vs spaces in examples
  * Provide accessor for source package version for binary packages
- Update to 0.1.38
  * Add SHA265 support to handling of pdiffs
  * Add support for additional headers for merged pdiffs to PDiffIndex
  * Allow debian_support.patches_from_ed_script to consume both bytes and str
  * Add a debian.watch module for parsing watch files
  * Prevent stripping of last newline in initial lines before changelog files
  * Add a Copyright.files_excluded field
  * Allow specifying allow_missing_author when reserializing changelog
    entries
- Update to 0.1.37
  * Drop python2 support
  * Update Standards-Version to 4.5.0 (no changes required)
  * Add Rules-Requires-Root: no
  * Parse Built-Using relationship fields
* Thu Sep  5 2019 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- Update to 0.1.36
  * Update Standards-Version to 4.4.0 (no changes required).
  * Update to debhelper-compat 12.
  * Extend Deb822 parser to allow underscores in the field name
  * Add accessors for Version objects from Deb822
  * Miscellaneous bug fixes.
* Mon Nov  5 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Dec 19 2017 carmen@carmenbianca.eu
- Created package, version 0.1.31.
